**Flycheck** is a modern on-the-fly syntax checking extension for GNU Emacs 24,
intended as replacement for the older Flymake extension which is part of GNU
Emacs.

It uses various syntax checking and linting tools to
[automatically check the contents of buffers][checking] while you type, and
reports warnings and errors directly in the buffer or in an optional error list
(see [Flycheck manual][manual] for more information):

![](/usr/share/doc/elpa-flycheck/examples/flycheck-annotated.png)

Out of the box Flycheck supports over
[40 different programming languages][languages] with more than 80 different
syntax checking tools, and comes with a [simple interface][definitions] to
define new syntax checkers.

Many [3rd party extensions][extensions] provide new syntax checkers and other
features like alternative error displays or mode line indicators.

[manual]: http://www.flycheck.org/en/latest/index.html#the-user-guide
[checking]: http://www.flycheck.org/en/latest/_downloads/flycheck.html#Checking-buffers
[languages]:http://www.flycheck.org/en/latest/languages.html
[definitions]: http://www.flycheck.org/en/latest/_downloads/flycheck.html#Defining-syntax-checkers
[extensions]: http://www.flycheck.org/en/latest/community/extensions.html

## Quickstart ##

Flycheck needs GNU Emacs 24.3 or newer, and works best on Unix systems.

Install some [syntax checker tools][languages] and type the following in your
`*scratch*` buffer and run `M-x eval-buffer`:

```lisp
(require 'package)
(add-to-list 'package-archives
             '("melpa" . "http://stable.melpa.org/packages/") t)
(package-initialize)

(package-install 'flycheck)

(global-flycheck-mode)
```

For a more gentle introduction go through [Quickstart][] guide.

[Quickstart]: http://www.flycheck.org/en/latest/user/quickstart.html

## Support & Contribution ##

Please ask questions about Flycheck on [Stack Exchange][sx] or in our
[Gitter chat][gitter].  We try to answer all questions as fast and as precise as
possible.

To report problems or bugs, please use our [issue tracker][].  Our
[Contributor’s Guide][contrib] helps you to create good bug reports; please take
a look.

We welcome patches and pull requests that fix bugs or provide new features.
Please read our [Contributor’s Guide][contrib] for help and guidance before
submitting pull requests.  When making larger changes to Flycheck or
implementing new features we recommend that you first open a separate issue or
ask in our [Gitter channel][gitter] to discuss you intended changes.

All contributors and all participants in our communication channels are expected
to follow our [Code of Conduct][coc].

[sx]: https://emacs.stackexchange.com/questions/tagged/flycheck
[gitter]: https://gitter.im/flycheck/flycheck
[Issue Tracker]: https://github.com/flycheck/flycheck/issues
[contrib]: http://www.flycheck.org/en/latest/contributor/contributing.html
[Waffle Board]: http://waffle.io/flycheck/flycheck
[coc]: http://www.flycheck.org/en/latest/community/conduct.html
